summaryrefslogtreecommitdiff
path: root/formula
diff options
context:
space:
mode:
authorLaurent Charrière <lcharriere@gmail.com>2015-01-12 19:56:39 +0100
committerEike Rathke <erack@redhat.com>2015-01-14 19:52:07 +0000
commit1f56cbf8cc15f76131d1dc8801935bec92be05ea (patch)
tree4fc480b6ba409d9a68aee78130df7693e12b43b2 /formula
parent975832d885ca5d185e91a975b157bf06bf9a7a0e (diff)
sc: rename ocChose et al. to ocChoose et al.
Change-Id: I1aa8ee6c827a6d6a6c6beb190bdc9c3c91d82b22 Reviewed-on: https://gerrit.libreoffice.org/13889 Reviewed-by: Eike Rathke <erack@redhat.com> Tested-by: Eike Rathke <erack@redhat.com>
Diffstat (limited to 'formula')
-rw-r--r--formula/source/core/api/FormulaCompiler.cxx10
-rw-r--r--formula/source/core/api/token.cxx14
-rw-r--r--formula/source/core/resource/core_resource.src8
3 files changed, 16 insertions, 16 deletions
diff --git a/formula/source/core/api/FormulaCompiler.cxx b/formula/source/core/api/FormulaCompiler.cxx
index 55a1063b1f75..39083786aa5c 100644
--- a/formula/source/core/api/FormulaCompiler.cxx
+++ b/formula/source/core/api/FormulaCompiler.cxx
@@ -465,7 +465,7 @@ uno::Sequence< sheet::FormulaOpCodeMapEntry > FormulaCompiler::OpCodeMap::create
SC_OPCODE_IF,
SC_OPCODE_IF_ERROR,
SC_OPCODE_IF_NA,
- SC_OPCODE_CHOSE,
+ SC_OPCODE_CHOOSE,
SC_OPCODE_AND,
SC_OPCODE_OR,
SC_OPCODE_NOT,
@@ -814,7 +814,7 @@ bool FormulaCompiler::IsOpCodeJumpCommand( OpCode eOp )
case ocIf:
case ocIfError:
case ocIfNA:
- case ocChose:
+ case ocChoose:
return true;
default:
;
@@ -1318,7 +1318,7 @@ void FormulaCompiler::Factor()
case ocIf:
pFacToken->GetJump()[ 0 ] = 3; // if, else, behind
break;
- case ocChose:
+ case ocChoose:
pFacToken->GetJump()[ 0 ] = FORMULA_MAXJUMPCOUNT + 1;
break;
case ocIfError:
@@ -1348,7 +1348,7 @@ void FormulaCompiler::Factor()
case ocIf:
nJumpMax = 3;
break;
- case ocChose:
+ case ocChoose:
nJumpMax = FORMULA_MAXJUMPCOUNT;
break;
case ocIfError:
@@ -1385,7 +1385,7 @@ void FormulaCompiler::Factor()
case ocIf:
bLimitOk = (nJumpCount <= 3);
break;
- case ocChose:
+ case ocChoose:
bLimitOk = (nJumpCount < FORMULA_MAXJUMPCOUNT); /* TODO: check, really <, not <=? */
break;
case ocIfError:
diff --git a/formula/source/core/resource/core_resource.src b/formula/source/core/resource/core_resource.src
index 3dfec5cce236..3d28399ab83e 100644
--- a/formula/source/core/resource/core_resource.src
+++ b/formula/source/core/resource/core_resource.src
@@ -27,7 +27,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH_ODFF
String SC_OPCODE_IF { Text = "IF" ; };
String SC_OPCODE_IF_ERROR { Text = "IFERROR" ; };
String SC_OPCODE_IF_NA { Text = "IFNA" ; };
- String SC_OPCODE_CHOSE { Text = "CHOOSE" ; };
+ String SC_OPCODE_CHOOSE { Text = "CHOOSE" ; };
String SC_OPCODE_OPEN { Text = "(" ; };
String SC_OPCODE_CLOSE { Text = ")" ; };
String SC_OPCODE_ARRAY_OPEN { Text = "{" ; };
@@ -435,7 +435,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH_OOXML
String SC_OPCODE_IF { Text = "IF" ; };
String SC_OPCODE_IF_ERROR { Text = "IFERROR" ; };
String SC_OPCODE_IF_NA { Text = "_xlfn.IFNA" ; };
- String SC_OPCODE_CHOSE { Text = "CHOOSE" ; };
+ String SC_OPCODE_CHOOSE { Text = "CHOOSE" ; };
String SC_OPCODE_OPEN { Text = "(" ; };
String SC_OPCODE_CLOSE { Text = ")" ; };
String SC_OPCODE_ARRAY_OPEN { Text = "{" ; };
@@ -845,7 +845,7 @@ Resource RID_STRLIST_FUNCTION_NAMES_ENGLISH
String SC_OPCODE_IF { Text = "IF" ; };
String SC_OPCODE_IF_ERROR { Text = "IFERROR" ; };
String SC_OPCODE_IF_NA { Text = "IFNA" ; };
- String SC_OPCODE_CHOSE { Text = "CHOOSE" ; };
+ String SC_OPCODE_CHOOSE { Text = "CHOOSE" ; };
String SC_OPCODE_OPEN { Text = "(" ; };
String SC_OPCODE_CLOSE { Text = ")" ; };
String SC_OPCODE_ARRAY_OPEN { Text = "{" ; };
@@ -1261,7 +1261,7 @@ Resource RID_STRLIST_FUNCTION_NAMES
{
Text [ en-US ] = "IFNA" ;
};
- String SC_OPCODE_CHOSE
+ String SC_OPCODE_CHOOSE
{
Text [ en-US ] = "CHOOSE" ;
};
diff --git a/formula/source/core/api/token.cxx b/formula/source/core/api/token.cxx
index 0ae70594c2db..e033835685e5 100644
--- a/formula/source/core/api/token.cxx
+++ b/formula/source/core/api/token.cxx
@@ -81,7 +81,7 @@ bool FormulaToken::IsFunction() const
eOp != ocColRowNameAuto && eOp != ocName && eOp != ocDBArea &&
(GetByte() != 0 // x parameters
|| (SC_OPCODE_START_NO_PAR <= eOp && eOp < SC_OPCODE_STOP_NO_PAR) // no parameter
- || (ocIf == eOp || ocIfError == eOp || ocIfNA == eOp || ocChose == eOp ) // @ jump commands
+ || (ocIf == eOp || ocIfError == eOp || ocIfNA == eOp || ocChoose == eOp ) // @ jump commands
|| (SC_OPCODE_START_1_PAR <= eOp && eOp < SC_OPCODE_STOP_1_PAR) // one parameter
|| (SC_OPCODE_START_2_PAR <= eOp && eOp < SC_OPCODE_STOP_2_PAR) // x parameters (cByte==0 in
// FuncAutoPilot)
@@ -96,10 +96,10 @@ bool FormulaToken::IsFunction() const
sal_uInt8 FormulaToken::GetParamCount() const
{
if ( eOp < SC_OPCODE_STOP_DIV && eOp != ocExternal && eOp != ocMacro &&
- eOp != ocIf && eOp != ocIfError && eOp != ocIfNA && eOp != ocChose &&
+ eOp != ocIf && eOp != ocIfError && eOp != ocIfNA && eOp != ocChoose &&
eOp != ocPercentSign )
return 0; // parameters and specials
// ocIf, ocIfError, ocIfNA and ocChose not for FAP, have cByte then
//2do: bool parameter whether FAP or not?
else if ( GetByte() )
return GetByte(); // all functions, also ocExternal and ocMacro
@@ -112,7 +112,7 @@ sal_uInt8 FormulaToken::GetParamCount() const
return 0; // no parameter
else if (SC_OPCODE_START_1_PAR <= eOp && eOp < SC_OPCODE_STOP_1_PAR)
return 1; // one parameter
- else if ( eOp == ocIf || eOp == ocIfError || eOp == ocIfNA || eOp == ocChose )
+ else if ( eOp == ocIf || eOp == ocIfError || eOp == ocIfNA || eOp == ocChoose )
return 1; // only the condition counts as parameter
else
return 0; // all the rest, no Parameter, or
@@ -967,7 +967,7 @@ bool FormulaTokenArray::HasMatrixDoubleRefOps()
}
if ( eOp == ocPush || lcl_IsReference( eOp, t->GetType() ) )
pStack[sp++] = t;
- else if ( eOp == ocIf || eOp == ocIfError || eOp == ocIfNA || eOp == ocChose )
+ else if ( eOp == ocIf || eOp == ocIfError || eOp == ocIfNA || eOp == ocChoose )
{ // ignore Jumps, pop previous Result (Condition)
if ( sp )
--sp;
@@ -1441,12 +1441,12 @@ FormulaToken* FormulaTokenArray::AddOpCode( OpCode eOp )
case ocIf:
case ocIfError:
case ocIfNA:
- case ocChose:
+ case ocChoose:
{
short nJump[FORMULA_MAXJUMPCOUNT + 1];
if ( eOp == ocIf )
nJump[ 0 ] = 3;
- else if ( eOp == ocChose )
+ else if ( eOp == ocChoose )
nJump[ 0 ] = FORMULA_MAXJUMPCOUNT + 1;
else
nJump[ 0 ] = 2;
@@ -96,10 +96,10 @@ bool FormulaToken::IsFunction() const
eOp != ocPercentSign )
return 0; // parameters and specials
- // ocIf, ocIfError, ocIfNA and ocChose not for FAP, have cByte then
+ // ocIf, ocIfError, ocIfNA and ocChoose not for FAP, have cByte then
//2do: bool parameter whether FAP or not?
else if ( GetByte() )